@@ -40,7 +40,7 @@ from PIL import ImageFont
 
 __author__ = 'Harald Hetzner'
 __license__ = 'BSD 3-Clause License'
-__version__ = '2.0.1'
+__version__ = '2.0.2'
 
 class Parameters:
     """
@@ -314,7 +314,8 @@ class VideoThumbnailer:
                                 '.mov',
                                 '.mp4',
                                 '.mpg',
-                                '.wmv')
+                                '.wmv',
+                                '.mts')
 
     def __init__(self):
         """
@@ -374,7 +375,7 @@ class VideoThumbnailer:
         parser.add_argument('--rows',
                              type=int,
                              help='The number of preview thumbnail rows.')
-        parser.add_argument('---vertical-video-columns',
+        parser.add_argument('--vertical-video-columns',
                              type=int,
                              help='The number of preview thumbnail columns in place of \'--columns\' in case of vertical videos.')
         parser.add_argument('--vertical-video-rows',
